<!DOCTYPE html>
<html>

<head>
    <meta charset="utf-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>Page Title</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css" integrity="sha384-Gn5384xqQ1aoWXA+058RXPxPg6fy4IWvTNh0E263XmFcJlSAwiGgFAW/dAiS6JXm"
        crossorigin="anonymous">
    <style>
        body {
            padding: 5px
        }

        .obj {
            color: #e00000;
        }

        .obj-property-name {
            margin-left: 1em;
            color: #922b92;
        }

        .obj-property-type {
            color: #e00000;
        }

        .obj-propert-type-item {
            margin-left: 3em;
            line-height: 26px;
        }
    </style>
</head>

<body>
    <div class="container-fluid">
        <div class="row">
            <span class="obj">{{ obj.__class__.__name__}}</span> {{ obj }}
        </div>
        {% for key, property in properties %}
            {% include 'obj_loop.html' %}
        {% endfor %}
    </div>


</body>

</html>